cmd/dist: do not run on ppc64le

Also don't run on all the other tiny slow boxes we have.
Should fix the remaining ppc64le broken builders.

For #44505 (or at least somehow provoked by it).

Change-Id: I72e8086cb641f3f7da3a872140a752bf328eec1f
Reviewed-on: https://go-review.googlesource.com/c/go/+/421438
Reviewed-by: Heschi Kreinick <heschi@google.com>
TryBot-Result: Gopher Robot <gobot@golang.org>
Auto-Submit: Russ Cox <rsc@golang.org>
Run-TryBot: Russ Cox <rsc@golang.org>
diff --git a/src/cmd/dist/test.go b/src/cmd/dist/test.go
index da5b179..536a214 100644
--- a/src/cmd/dist/test.go
+++ b/src/cmd/dist/test.go
@@ -866,12 +866,12 @@
 			})
 		}
 	}
-	// Only run the API check on fast development platforms. Android, iOS, and JS
-	// are always cross-compiled, and the filesystems on our only plan9 builders
-	// are too slow to complete in a reasonable timeframe. Every platform checks
-	// the API on every GOOS/GOARCH/CGO_ENABLED combination anyway, so we really
-	// only need to run this check once anywhere to get adequate coverage.
-	if goos != "android" && !t.iOS() && goos != "js" && goos != "plan9" {
+	// Only run the API check on fast development platforms.
+	// Every platform checks the API on every GOOS/GOARCH/CGO_ENABLED combination anyway,
+	// so we really only need to run this check once anywhere to get adequate coverage.
+	// To help developers avoid trybot-only failures, we try to run on typical developer machines
+	// which is darwin/linux/windows and amd64/arm64.
+	if (goos == "darwin" || goos == "linux" || goos == "windows") && (goarch == "amd64" || goarch == "arm64") {
 		t.tests = append(t.tests, distTest{
 			name:    "api",
 			heading: "API check",